@@ -3,7 +3,7 @@ from feat.models import model, value
 from feat.models import effect, call
 
 import demo_service
-
+register = model.get_registry().register
 
 @adapter.register(demo_service.Service, model.IModel)
 class Service(model.Model):
@@ -13,6 +13,7 @@ class Service(model.Model):
     model.child("documents", model="service.documents")
 
 
+@register
 class Documents(model.Collection):
     model.identity("service.documents")
     model.child_model("service.documents.CATEGORY")
@@ -20,6 +21,7 @@ class Documents(model.Collection):
     model.child_source(effect.context_value("key"))
 
 
+@register
 class Category(model.Model):
     model.identity("service.documents.CATEGORY")
     model.attribute("category", value.String(),
