@@ -62,6 +62,9 @@ class IntegrationTest(common.TestCase):
 
     def setUp(self):
         self.assert_not_skipped()
+        feat.load_adapters()
+        self.addCleanup(feat.unload_adapters)
+
         return common.TestCase.setUp(self)
 
     def assert_not_skipped(self):
